@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::AssertOS;
-BEGIN {
-  $Dist::Zilla::Plugin::AssertOS::VERSION = '0.04';
+{
+  $Dist::Zilla::Plugin::AssertOS::VERSION = '0.06';
 }
 
 # ABSTRACT: Require that our distribution is running on a particular OS
@@ -9,6 +9,7 @@ use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::InstallTool';
 with 'Dist::Zilla::Role::MetaProvider';
+with 'Dist::Zilla::Role::PrereqSource';
 
 use File::Spec;
 
@@ -21,6 +22,12 @@ has 'os' => (
     auto_deref => 1,
 );
 
+has 'bundle' => (
+    is      => 'ro',
+    isa     => 'Bool',
+    default => 1,
+);
+
 sub metadata {
   return {
     no_index => {
@@ -29,9 +36,24 @@ sub metadata {
   };
 }
 
+sub register_prereqs {
+  my $self = shift;
+  return if $self->bundle;
+  $self->zilla->register_prereqs(
+    {
+      phase => 'configure',
+      type  => 'requires',
+    },
+    'Devel::CheckOS'  => '1.63',
+    'Devel::AssertOS' => '0',
+  );
+}
+
 sub gather_files {
   my $self = shift;
-  
+
+  return unless $self->bundle;
+
   require Data::Compare;
 
   foreach my $os ( $self->os ) {
@@ -59,13 +81,13 @@ sub gather_files {
     my @dircomponents = ('inc', (split(/::/, $module)));
     my $file = pop @dircomponents;
 
-    { 
+    {
       open(my $PM, $fullfilename) ||
         die("Can't read $fullfilename: $!");
       local $/ = undef;
       (my $content = <$PM>) =~ s/package Devel::/package #\nDevel::/;
       close($PM);
-      
+
       my $pm = Dist::Zilla::File::InMemory->new({
          content => $content,
          name    => File::Spec->catfile(@dircomponents, $file),
@@ -78,12 +100,19 @@ sub gather_files {
   return;
 }
 
+# XXX - this should really be a separate phase that runs after InstallTool -
+# until then, all we can do is die if we are run too soon
 sub setup_installer {
   my $self = shift;
+
   my @mfpl = grep { $_->name eq 'Makefile.PL' or $_->name eq 'Build.PL' } @{ $self->zilla->files };
-  return unless @mfpl;
+
+  $self->log_fatal('No Makefile.PL or Build.PL was found. [AssertOS] should appear in dist.ini after [MakeMaker] or [ModuleBuild]!') unless @mfpl;
+
   for my $mfpl ( @mfpl ) {
-    my $content = qq{use lib 'inc';\nuse Devel::AssertOS qw[};
+    my $content = qq{};
+    $content .= qq{use lib 'inc';\n} if $self->bundle;
+    $content .= qq{use Devel::AssertOS qw[};
     $content .= join ' ', $self->os;
     $content .= "];\n";
     $mfpl->content( $content . $mfpl->content );
@@ -94,10 +123,10 @@ sub setup_installer {
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
-qq[run run Reynard]
-
+qq[run run Reynard];
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -106,7 +135,7 @@ Dist::Zilla::Plugin::AssertOS - Require that our distribution is running on a pa
 
 =head1 VERSION
 
-version 0.04
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -127,16 +156,16 @@ The resultant distribution will die at C<Makefile.PL> unless the platform the co
 Dist::Zilla::Plugin::AssertOS is a L<Dist::Zilla> plugin that integrates L<Devel::AssertOS> so that CPAN authors
 may easily stipulate which particular OS environments their distributions may be built and installed on.
 
-The author specifies which OS or OS families are supported. The necessary L<Devel::AssertOS> files are copied to the 
+The author specifies which OS or OS families are supported. The necessary L<Devel::AssertOS> files are copied to the
 C<inc/> directory and C<Makefile.PL> or C<Build.PL> is mungled to include the necessary incantation.
 
-On the module user side, the bundled C<inc/> L<Devel::AssertOS> determines whether the current environment is 
+On the module user side, the bundled C<inc/> L<Devel::AssertOS> determines whether the current environment is
 supported or not and will die accordingly.
 
-As this plugin mungles the C<Makefile.PL>/C<Build.PL> it is imperative that it is specified in C<dist.ini> 
+As this plugin mungles the C<Makefile.PL>/C<Build.PL> it is imperative that it is specified in C<dist.ini>
 AFTER C<[MakeMaker]> or C<[ModuleBuild]>.
 
-This plugin also automagically adds the C<no_index> metadata so that C<inc/> is excluded from PAUSE indexing. If 
+This plugin also automagically adds the C<no_index> metadata so that C<inc/> is excluded from PAUSE indexing. If
 you use L<Dist::Zilla::Plugin::MetaNoIndex>, there may be conflicts.
 
 =head2 ATTRIBUTES
@@ -148,6 +177,12 @@ you use L<Dist::Zilla::Plugin::MetaNoIndex>, there may be conflicts.
 Specify as many times as wanted the OS that you wish your distribution to work with. See L<Devel::AssertOS> and
 L<Devel::CheckOS> for what may be given.
 
+=item C<bundle>
+
+If set to c<0> L<Devel::AssertOS> will not be bundled in the distribution. It will instead be added to
+C<configure_requires> in the C<META> files so CPAN clients can install it before running C<Makefile.PL>.
+The default is C<1>, so L<Devel::AssertOS> is bundled in C<inc>.
+
 =back
 
 =head2 METHODS
@@ -172,6 +207,8 @@ Required by L<Dist::Zilla::Role::MetaProvider>.
 
 =back
 
+=for Pod::Coverage   register_prereqs
+
 =head1 KUDOS
 
 Based on L<use-devel-assertos> by David Cantrell
@@ -195,10 +232,9 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Chris Williams and David Cantrell.
+This software is copyright (c) 2013 by Chris Williams and David Cantrell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
